==> easybuild-framework-4.6.0.tar.gz: easybuild-framework-4.6.0/easybuild/toolchains/gobff.py <==
##
# Copyright 2013-2022 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
EasyBuild support for gobff compiler toolchain (includes GCC, OpenMPI, BLIS, libFLAME, ScaLAPACK and FFTW).

:author: Sebastian Achilles (Forschungszentrum Juelich GmbH)
"""

from easybuild.toolchains.gompi import Gompi
from easybuild.toolchains.linalg.blis import Blis
from easybuild.toolchains.linalg.flame import Flame
from easybuild.toolchains.linalg.scalapack import ScaLAPACK
from easybuild.toolchains.fft.fftw import Fftw


class Gobff(Gompi, Blis, Flame, ScaLAPACK, Fftw):
    """Compiler toolchain with GCC, OpenMPI, BLIS, libFLAME, ScaLAPACK and FFTW."""
    NAME = 'gobff'
    SUBTOOLCHAIN = Gompi.NAME

==> easybuild-framework-4.7.0.tar.gz: easybuild-framework-4.7.0/easybuild/toolchains/gobff.py <==
##
# Copyright 2013-2023 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
EasyBuild support for gobff compiler toolchain (includes GCC, OpenMPI, BLIS, libFLAME, ScaLAPACK and FFTW).

Authors:

* Sebastian Achilles (Forschungszentrum Juelich GmbH)
"""

from easybuild.toolchains.gompi import Gompi
from easybuild.toolchains.linalg.blis import Blis
from easybuild.toolchains.linalg.flame import Flame
from easybuild.toolchains.linalg.scalapack import ScaLAPACK
from easybuild.toolchains.fft.fftw import Fftw


class Gobff(Gompi, Blis, Flame, ScaLAPACK, Fftw):
    """Compiler toolchain with GCC, OpenMPI, BLIS, libFLAME, ScaLAPACK and FFTW."""
    NAME = 'gobff'
    SUBTOOLCHAIN = Gompi.NAME
